@@ -1,5 +1,5 @@
 use crate::PortalMessage;
-use async_trait::async_trait;
+use ockam_core::async_trait;
 use ockam_core::compat::collections::VecDeque;
 use ockam_core::{
     Address, Any, Decodable, LocalMessage, Result, Route, Routed, TransportMessage, Worker,
@@ -98,15 +98,14 @@ impl Worker for TcpPortalSendWorker {
 
         if recipient == self.internal_address {
             // Forward message
-            let payload = msg.payload().clone();
+            let payload = msg.payload().to_vec();
             if let Some(r) = &self.onward_route {
                 let msg = TransportMessage::v1(r.clone(), self.remote_address.clone(), payload);
                 ctx.forward(LocalMessage::new(msg, Vec::new())).await?;
             } else {
                 self.buffer.push_back(payload);
             }
-        }
-        if self.onward_route.is_none() {
+        } else if self.onward_route.is_none() {
             // TODO: This should be serialized empty vec
             if msg.payload().len() != 1 {
                 return Err(TransportError::Protocol.into());
